@@ -163,7 +163,7 @@ pub mod msg_client {
     where
         T: tonic::client::GrpcService<tonic::body::BoxBody>,
         T::Error: Into<StdError>,
-        T::ResponseBody: Default + Body<Data = Bytes> + Send + 'static,
+        T::ResponseBody: Default + Body<Data = prost::bytes::Bytes> + Send + 'static,
         <T::ResponseBody as Body>::Error: Into<StdError> + Send,
     {
         pub fn new(inner: T) -> Self {
@@ -292,28 +292,6 @@ pub struct QueryAllBalancesResponse {
     #[prost(message, optional, tag="2")]
     pub pagination: ::core::option::Option<super::super::base::query::v1beta1::PageResponse>,
 }
-/// QuerySpendableBalancesRequest defines the gRPC request structure for querying
-/// an account's spendable balances.
-#[derive(Clone, PartialEq, ::prost::Message)]
-pub struct QuerySpendableBalancesRequest {
-    /// address is the address to query spendable balances for.
-    #[prost(string, tag="1")]
-    pub address: ::prost::alloc::string::String,
-    /// pagination defines an optional pagination for the request.
-    #[prost(message, optional, tag="2")]
-    pub pagination: ::core::option::Option<super::super::base::query::v1beta1::PageRequest>,
-}
-/// QuerySpendableBalancesResponse defines the gRPC response structure for querying
-/// an account's spendable balances.
-#[derive(Clone, PartialEq, ::prost::Message)]
-pub struct QuerySpendableBalancesResponse {
-    /// balances is the spendable balances of all the coins.
-    #[prost(message, repeated, tag="1")]
-    pub balances: ::prost::alloc::vec::Vec<super::super::base::v1beta1::Coin>,
-    /// pagination defines the pagination in the response.
-    #[prost(message, optional, tag="2")]
-    pub pagination: ::core::option::Option<super::super::base::query::v1beta1::PageResponse>,
-}
 /// QueryTotalSupplyRequest is the request type for the Query/TotalSupply RPC
 /// method.
 #[derive(Clone, PartialEq, ::prost::Message)]
@@ -418,7 +396,7 @@ pub mod query_client {
     where
         T: tonic::client::GrpcService<tonic::body::BoxBody>,
         T::Error: Into<StdError>,
-        T::ResponseBody: Default + Body<Data = Bytes> + Send + 'static,
+        T::ResponseBody: Default + Body<Data = prost::bytes::Bytes> + Send + 'static,
         <T::ResponseBody as Body>::Error: Into<StdError> + Send,
     {
         pub fn new(inner: T) -> Self {
@@ -498,30 +476,6 @@ pub mod query_client {
             );
             self.inner.unary(request.into_request(), path, codec).await
         }
-        /// SpendableBalances queries the spenable balance of all coins for a single
-        /// account.
-        pub async fn spendable_balances(
-            &mut self,
-            request: impl tonic::IntoRequest<super::QuerySpendableBalancesRequest>,
-        ) -> Result<
-                tonic::Response<super::QuerySpendableBalancesResponse>,
-                tonic::Status,
-            > {
-            self.inner
-                .ready()
-                .await
-                .map_err(|e| {
-                    tonic::Status::new(
-                        tonic::Code::Unknown,
-                        format!("Service was not ready: {}", e.into()),
-                    )
-                })?;
-            let codec = tonic::codec::ProstCodec::default();
-            let path = http::uri::PathAndQuery::from_static(
-                "/cosmos.bank.v1beta1.Query/SpendableBalances",
-            );
-            self.inner.unary(request.into_request(), path, codec).await
-        }
         /// TotalSupply queries the total supply of all coins.
         pub async fn total_supply(
             &mut self,
