@@ -1,3 +1,16 @@
+/// Equivocation implements the Evidence interface and defines evidence of double
+/// signing misbehavior.
+#[derive(Clone, PartialEq, ::prost::Message)]
+pub struct Equivocation {
+    #[prost(int64, tag="1")]
+    pub height: i64,
+    #[prost(message, optional, tag="2")]
+    pub time: ::core::option::Option<::prost_types::Timestamp>,
+    #[prost(int64, tag="3")]
+    pub power: i64,
+    #[prost(string, tag="4")]
+    pub consensus_address: ::prost::alloc::string::String,
+}
 /// GenesisState defines the evidence module's genesis state.
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct GenesisState {
@@ -62,7 +75,7 @@ pub mod query_client {
     where
         T: tonic::client::GrpcService<tonic::body::BoxBody>,
         T::Error: Into<StdError>,
-        T::ResponseBody: Default + Body<Data = Bytes> + Send + 'static,
+        T::ResponseBody: Default + Body<Data = prost::bytes::Bytes> + Send + 'static,
         <T::ResponseBody as Body>::Error: Into<StdError> + Send,
     {
         pub fn new(inner: T) -> Self {
@@ -144,19 +157,6 @@ pub mod query_client {
         }
     }
 }
-/// Equivocation implements the Evidence interface and defines evidence of double
-/// signing misbehavior.
-#[derive(Clone, PartialEq, ::prost::Message)]
-pub struct Equivocation {
-    #[prost(int64, tag="1")]
-    pub height: i64,
-    #[prost(message, optional, tag="2")]
-    pub time: ::core::option::Option<::prost_types::Timestamp>,
-    #[prost(int64, tag="3")]
-    pub power: i64,
-    #[prost(string, tag="4")]
-    pub consensus_address: ::prost::alloc::string::String,
-}
 /// MsgSubmitEvidence represents a message that supports submitting arbitrary
 /// Evidence of misbehavior such as equivocation or counterfactual signing.
 #[derive(Clone, PartialEq, ::prost::Message)]
@@ -197,7 +197,7 @@ pub mod msg_client {
     where
         T: tonic::client::GrpcService<tonic::body::BoxBody>,
         T::Error: Into<StdError>,
-        T::ResponseBody: Default + Body<Data = Bytes> + Send + 'static,
+        T::ResponseBody: Default + Body<Data = prost::bytes::Bytes> + Send + 'static,
         <T::ResponseBody as Body>::Error: Into<StdError> + Send,
     {
         pub fn new(inner: T) -> Self {
