@@ -5,10 +5,10 @@ pub struct BasicAllowance {
     /// spend_limit specifies the maximum amount of tokens that can be spent
     /// by this allowance and will be updated as tokens are spent. If it is
     /// empty, there is no spend limit and any amount of coins can be spent.
-    #[prost(message, repeated, tag = "1")]
+    #[prost(message, repeated, tag="1")]
     pub spend_limit: ::prost::alloc::vec::Vec<super::super::base::v1beta1::Coin>,
     /// expiration specifies an optional time when this allowance expires
-    #[prost(message, optional, tag = "2")]
+    #[prost(message, optional, tag="2")]
     pub expiration: ::core::option::Option<::prost_types::Timestamp>,
 }
 /// PeriodicAllowance extends Allowance to allow for both a maximum cap,
@@ -16,103 +16,101 @@ pub struct BasicAllowance {
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct PeriodicAllowance {
     /// basic specifies a struct of `BasicAllowance`
-    #[prost(message, optional, tag = "1")]
+    #[prost(message, optional, tag="1")]
     pub basic: ::core::option::Option<BasicAllowance>,
     /// period specifies the time duration in which period_spend_limit coins can
     /// be spent before that allowance is reset
-    #[prost(message, optional, tag = "2")]
+    #[prost(message, optional, tag="2")]
     pub period: ::core::option::Option<::prost_types::Duration>,
     /// period_spend_limit specifies the maximum number of coins that can be spent
     /// in the period
-    #[prost(message, repeated, tag = "3")]
+    #[prost(message, repeated, tag="3")]
     pub period_spend_limit: ::prost::alloc::vec::Vec<super::super::base::v1beta1::Coin>,
     /// period_can_spend is the number of coins left to be spent before the period_reset time
-    #[prost(message, repeated, tag = "4")]
+    #[prost(message, repeated, tag="4")]
     pub period_can_spend: ::prost::alloc::vec::Vec<super::super::base::v1beta1::Coin>,
     /// period_reset is the time at which this period resets and a new one begins,
     /// it is calculated from the start time of the first transaction after the
     /// last period ended
-    #[prost(message, optional, tag = "5")]
+    #[prost(message, optional, tag="5")]
     pub period_reset: ::core::option::Option<::prost_types::Timestamp>,
 }
 /// AllowedMsgAllowance creates allowance only for specified message types.
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct AllowedMsgAllowance {
     /// allowance can be any of basic and filtered fee allowance.
-    #[prost(message, optional, tag = "1")]
+    #[prost(message, optional, tag="1")]
     pub allowance: ::core::option::Option<::prost_types::Any>,
     /// allowed_messages are the messages for which the grantee has the access.
-    #[prost(string, repeated, tag = "2")]
+    #[prost(string, repeated, tag="2")]
     pub allowed_messages: ::prost::alloc::vec::Vec<::prost::alloc::string::String>,
 }
 /// Grant is stored in the KVStore to record a grant with full context
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct Grant {
     /// granter is the address of the user granting an allowance of their funds.
-    #[prost(string, tag = "1")]
+    #[prost(string, tag="1")]
     pub granter: ::prost::alloc::string::String,
     /// grantee is the address of the user being granted an allowance of another user's funds.
-    #[prost(string, tag = "2")]
+    #[prost(string, tag="2")]
     pub grantee: ::prost::alloc::string::String,
     /// allowance can be any of basic and filtered fee allowance.
-    #[prost(message, optional, tag = "3")]
+    #[prost(message, optional, tag="3")]
     pub allowance: ::core::option::Option<::prost_types::Any>,
 }
 /// GenesisState contains a set of fee allowances, persisted from the store
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct GenesisState {
-    #[prost(message, repeated, tag = "1")]
+    #[prost(message, repeated, tag="1")]
     pub allowances: ::prost::alloc::vec::Vec<Grant>,
 }
 /// QueryAllowanceRequest is the request type for the Query/Allowance RPC method.
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct QueryAllowanceRequest {
     /// granter is the address of the user granting an allowance of their funds.
-    #[prost(string, tag = "1")]
+    #[prost(string, tag="1")]
     pub granter: ::prost::alloc::string::String,
     /// grantee is the address of the user being granted an allowance of another user's funds.
-    #[prost(string, tag = "2")]
+    #[prost(string, tag="2")]
     pub grantee: ::prost::alloc::string::String,
 }
 /// QueryAllowanceResponse is the response type for the Query/Allowance RPC method.
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct QueryAllowanceResponse {
     /// allowance is a allowance granted for grantee by granter.
-    #[prost(message, optional, tag = "1")]
+    #[prost(message, optional, tag="1")]
     pub allowance: ::core::option::Option<Grant>,
 }
 /// QueryAllowancesRequest is the request type for the Query/Allowances RPC method.
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct QueryAllowancesRequest {
-    #[prost(string, tag = "1")]
+    #[prost(string, tag="1")]
     pub grantee: ::prost::alloc::string::String,
     /// pagination defines an pagination for the request.
-    #[prost(message, optional, tag = "2")]
+    #[prost(message, optional, tag="2")]
     pub pagination: ::core::option::Option<super::super::base::query::v1beta1::PageRequest>,
 }
 /// QueryAllowancesResponse is the response type for the Query/Allowances RPC method.
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct QueryAllowancesResponse {
     /// allowances are allowance's granted for grantee by granter.
-    #[prost(message, repeated, tag = "1")]
+    #[prost(message, repeated, tag="1")]
     pub allowances: ::prost::alloc::vec::Vec<Grant>,
     /// pagination defines an pagination for the response.
-    #[prost(message, optional, tag = "2")]
+    #[prost(message, optional, tag="2")]
     pub pagination: ::core::option::Option<super::super::base::query::v1beta1::PageResponse>,
 }
-#[cfg(feature = "grpc")]
-#[cfg_attr(docsrs, doc(cfg(feature = "grpc")))]
-#[doc = r" Generated client implementations."]
+/// Generated client implementations.
 pub mod query_client {
     #![allow(unused_variables, dead_code, missing_docs, clippy::let_unit_value)]
     use tonic::codegen::*;
-    #[doc = " Query defines the gRPC querier service."]
+    /// Query defines the gRPC querier service.
     #[derive(Debug, Clone)]
     pub struct QueryClient<T> {
         inner: tonic::client::Grpc<T>,
     }
     impl QueryClient<tonic::transport::Channel> {
-        #[doc = r" Attempt to create a new client by connecting to a given endpoint."]
+        /// Attempt to create a new client by connecting to a given endpoint.
         pub async fn connect<D>(dst: D) -> Result<Self, tonic::transport::Error>
         where
             D: std::convert::TryInto<tonic::transport::Endpoint>,
@@ -125,8 +123,8 @@ pub mod query_client {
     impl<T> QueryClient<T>
     where
         T: tonic::client::GrpcService<tonic::body::BoxBody>,
-        T::ResponseBody: Body + Send + 'static,
         T::Error: Into<StdError>,
+        T::ResponseBody: Default + Body<Data = prost::bytes::Bytes> + Send + 'static,
         <T::ResponseBody as Body>::Error: Into<StdError> + Send,
     {
         pub fn new(inner: T) -> Self {
@@ -145,54 +143,65 @@ pub mod query_client {
                     <T as tonic::client::GrpcService<tonic::body::BoxBody>>::ResponseBody,
                 >,
             >,
-            <T as tonic::codegen::Service<http::Request<tonic::body::BoxBody>>>::Error:
-                Into<StdError> + Send + Sync,
+            <T as tonic::codegen::Service<
+                http::Request<tonic::body::BoxBody>,
+            >>::Error: Into<StdError> + Send + Sync,
         {
             QueryClient::new(InterceptedService::new(inner, interceptor))
         }
-        #[doc = r" Compress requests with `gzip`."]
-        #[doc = r""]
-        #[doc = r" This requires the server to support it otherwise it might respond with an"]
-        #[doc = r" error."]
+        /// Compress requests with `gzip`.
+        ///
+        /// This requires the server to support it otherwise it might respond with an
+        /// error.
+        #[must_use]
         pub fn send_gzip(mut self) -> Self {
             self.inner = self.inner.send_gzip();
             self
         }
-        #[doc = r" Enable decompressing responses with `gzip`."]
+        /// Enable decompressing responses with `gzip`.
+        #[must_use]
         pub fn accept_gzip(mut self) -> Self {
             self.inner = self.inner.accept_gzip();
             self
         }
-        #[doc = " Allowance returns fee granted to the grantee by the granter."]
+        /// Allowance returns fee granted to the grantee by the granter.
         pub async fn allowance(
             &mut self,
             request: impl tonic::IntoRequest<super::QueryAllowanceRequest>,
         ) -> Result<tonic::Response<super::QueryAllowanceResponse>, tonic::Status> {
-            self.inner.ready().await.map_err(|e| {
-                tonic::Status::new(
-                    tonic::Code::Unknown,
-                    format!("Service was not ready: {}", e.into()),
-                )
-            })?;
+            self.inner
+                .ready()
+                .await
+                .map_err(|e| {
+                    tonic::Status::new(
+                        tonic::Code::Unknown,
+                        format!("Service was not ready: {}", e.into()),
+                    )
+                })?;
             let codec = tonic::codec::ProstCodec::default();
-            let path =
-                http::uri::PathAndQuery::from_static("/cosmos.feegrant.v1beta1.Query/Allowance");
+            let path = http::uri::PathAndQuery::from_static(
+                "/cosmos.feegrant.v1beta1.Query/Allowance",
+            );
             self.inner.unary(request.into_request(), path, codec).await
         }
-        #[doc = " Allowances returns all the grants for address."]
+        /// Allowances returns all the grants for address.
         pub async fn allowances(
             &mut self,
             request: impl tonic::IntoRequest<super::QueryAllowancesRequest>,
         ) -> Result<tonic::Response<super::QueryAllowancesResponse>, tonic::Status> {
-            self.inner.ready().await.map_err(|e| {
-                tonic::Status::new(
-                    tonic::Code::Unknown,
-                    format!("Service was not ready: {}", e.into()),
-                )
-            })?;
+            self.inner
+                .ready()
+                .await
+                .map_err(|e| {
+                    tonic::Status::new(
+                        tonic::Code::Unknown,
+                        format!("Service was not ready: {}", e.into()),
+                    )
+                })?;
             let codec = tonic::codec::ProstCodec::default();
-            let path =
-                http::uri::PathAndQuery::from_static("/cosmos.feegrant.v1beta1.Query/Allowances");
+            let path = http::uri::PathAndQuery::from_static(
+                "/cosmos.feegrant.v1beta1.Query/Allowances",
+            );
             self.inner.unary(request.into_request(), path, codec).await
         }
     }
@@ -202,44 +211,44 @@ pub mod query_client {
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct MsgGrantAllowance {
     /// granter is the address of the user granting an allowance of their funds.
-    #[prost(string, tag = "1")]
+    #[prost(string, tag="1")]
     pub granter: ::prost::alloc::string::String,
     /// grantee is the address of the user being granted an allowance of another user's funds.
-    #[prost(string, tag = "2")]
+    #[prost(string, tag="2")]
     pub grantee: ::prost::alloc::string::String,
     /// allowance can be any of basic and filtered fee allowance.
-    #[prost(message, optional, tag = "3")]
+    #[prost(message, optional, tag="3")]
     pub allowance: ::core::option::Option<::prost_types::Any>,
 }
 /// MsgGrantAllowanceResponse defines the Msg/GrantAllowanceResponse response type.
 #[derive(Clone, PartialEq, ::prost::Message)]
-pub struct MsgGrantAllowanceResponse {}
+pub struct MsgGrantAllowanceResponse {
+}
 /// MsgRevokeAllowance removes any existing Allowance from Granter to Grantee.
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct MsgRevokeAllowance {
     /// granter is the address of the user granting an allowance of their funds.
-    #[prost(string, tag = "1")]
+    #[prost(string, tag="1")]
     pub granter: ::prost::alloc::string::String,
     /// grantee is the address of the user being granted an allowance of another user's funds.
-    #[prost(string, tag = "2")]
+    #[prost(string, tag="2")]
     pub grantee: ::prost::alloc::string::String,
 }
 /// MsgRevokeAllowanceResponse defines the Msg/RevokeAllowanceResponse response type.
 #[derive(Clone, PartialEq, ::prost::Message)]
-pub struct MsgRevokeAllowanceResponse {}
-#[cfg(feature = "grpc")]
-#[cfg_attr(docsrs, doc(cfg(feature = "grpc")))]
-#[doc = r" Generated client implementations."]
+pub struct MsgRevokeAllowanceResponse {
+}
+/// Generated client implementations.
 pub mod msg_client {
     #![allow(unused_variables, dead_code, missing_docs, clippy::let_unit_value)]
     use tonic::codegen::*;
-    #[doc = " Msg defines the feegrant msg service."]
+    /// Msg defines the feegrant msg service.
     #[derive(Debug, Clone)]
     pub struct MsgClient<T> {
         inner: tonic::client::Grpc<T>,
     }
     impl MsgClient<tonic::transport::Channel> {
-        #[doc = r" Attempt to create a new client by connecting to a given endpoint."]
+        /// Attempt to create a new client by connecting to a given endpoint.
         pub async fn connect<D>(dst: D) -> Result<Self, tonic::transport::Error>
         where
             D: std::convert::TryInto<tonic::transport::Endpoint>,
@@ -252,15 +261,18 @@ pub mod msg_client {
     impl<T> MsgClient<T>
     where
         T: tonic::client::GrpcService<tonic::body::BoxBody>,
-        T::ResponseBody: Body + Send + 'static,
         T::Error: Into<StdError>,
+        T::ResponseBody: Default + Body<Data = prost::bytes::Bytes> + Send + 'static,
         <T::ResponseBody as Body>::Error: Into<StdError> + Send,
     {
         pub fn new(inner: T) -> Self {
             let inner = tonic::client::Grpc::new(inner);
             Self { inner }
         }
-        pub fn with_interceptor<F>(inner: T, interceptor: F) -> MsgClient<InterceptedService<T, F>>
+        pub fn with_interceptor<F>(
+            inner: T,
+            interceptor: F,
+        ) -> MsgClient<InterceptedService<T, F>>
         where
             F: tonic::service::Interceptor,
             T: tonic::codegen::Service<
@@ -269,53 +281,63 @@ pub mod msg_client {
                     <T as tonic::client::GrpcService<tonic::body::BoxBody>>::ResponseBody,
                 >,
             >,
-            <T as tonic::codegen::Service<http::Request<tonic::body::BoxBody>>>::Error:
-                Into<StdError> + Send + Sync,
+            <T as tonic::codegen::Service<
+                http::Request<tonic::body::BoxBody>,
+            >>::Error: Into<StdError> + Send + Sync,
         {
             MsgClient::new(InterceptedService::new(inner, interceptor))
         }
-        #[doc = r" Compress requests with `gzip`."]
-        #[doc = r""]
-        #[doc = r" This requires the server to support it otherwise it might respond with an"]
-        #[doc = r" error."]
+        /// Compress requests with `gzip`.
+        ///
+        /// This requires the server to support it otherwise it might respond with an
+        /// error.
+        #[must_use]
         pub fn send_gzip(mut self) -> Self {
             self.inner = self.inner.send_gzip();
             self
         }
-        #[doc = r" Enable decompressing responses with `gzip`."]
+        /// Enable decompressing responses with `gzip`.
+        #[must_use]
         pub fn accept_gzip(mut self) -> Self {
             self.inner = self.inner.accept_gzip();
             self
         }
-        #[doc = " GrantAllowance grants fee allowance to the grantee on the granter's"]
-        #[doc = " account with the provided expiration time."]
+        /// GrantAllowance grants fee allowance to the grantee on the granter's
+        /// account with the provided expiration time.
         pub async fn grant_allowance(
             &mut self,
             request: impl tonic::IntoRequest<super::MsgGrantAllowance>,
         ) -> Result<tonic::Response<super::MsgGrantAllowanceResponse>, tonic::Status> {
-            self.inner.ready().await.map_err(|e| {
-                tonic::Status::new(
-                    tonic::Code::Unknown,
-                    format!("Service was not ready: {}", e.into()),
-                )
-            })?;
+            self.inner
+                .ready()
+                .await
+                .map_err(|e| {
+                    tonic::Status::new(
+                        tonic::Code::Unknown,
+                        format!("Service was not ready: {}", e.into()),
+                    )
+                })?;
             let codec = tonic::codec::ProstCodec::default();
-            let path =
-                http::uri::PathAndQuery::from_static("/cosmos.feegrant.v1beta1.Msg/GrantAllowance");
+            let path = http::uri::PathAndQuery::from_static(
+                "/cosmos.feegrant.v1beta1.Msg/GrantAllowance",
+            );
             self.inner.unary(request.into_request(), path, codec).await
         }
-        #[doc = " RevokeAllowance revokes any fee allowance of granter's account that"]
-        #[doc = " has been granted to the grantee."]
+        /// RevokeAllowance revokes any fee allowance of granter's account that
+        /// has been granted to the grantee.
         pub async fn revoke_allowance(
             &mut self,
             request: impl tonic::IntoRequest<super::MsgRevokeAllowance>,
         ) -> Result<tonic::Response<super::MsgRevokeAllowanceResponse>, tonic::Status> {
-            self.inner.ready().await.map_err(|e| {
-                tonic::Status::new(
-                    tonic::Code::Unknown,
-                    format!("Service was not ready: {}", e.into()),
-                )
-            })?;
+            self.inner
+                .ready()
+                .await
+                .map_err(|e| {
+                    tonic::Status::new(
+                        tonic::Code::Unknown,
+                        format!("Service was not ready: {}", e.into()),
+                    )
+                })?;
             let codec = tonic::codec::ProstCodec::default();
             let path = http::uri::PathAndQuery::from_static(
                 "/cosmos.feegrant.v1beta1.Msg/RevokeAllowance",
